:mod:`lck.django.common`
========================

.. automodule:: lck.django.common


Rendering functions
-------------------

.. autofunction:: redirect

.. autofunction:: render

.. autofunction:: render_json

.. autofunction:: typical_handler

Decorators
----------

.. autofunction:: nested_commit_on_success

Misc
----

.. autofunction:: cut

.. autoclass:: lazy_chain
   :members:

.. autofunction:: remote_addr
